%Estimation of pressure loss in fracture and near wellbore
clc; clear all
%Physical parameters
nn = 6; %number of different cases


L = 500; %Fracture length [m]
w = 100; %fracture widt [m]


re = w/2;
rw = 0.15;

h = linspace(0.5,3,100)'/1000*ones(1,8); %fracture aperture [m]

m_fracture = 0.08*w; %massflow [kg/s per unit width]


eh = ones(100,1)*linspace(0.1,0.8,8); %Roughness divided by fracture aperture
theta = pi;


%physical properties Water
    Cp_w = 4250; %specific heat of water [J/kg K]
    rho_w = 950; %Density water [kg/m^3]
    k_w = 0.68; %Thermal conductivity of water [W/mK]
    mu = 0.260*10^(-3); %dynamic viscosity [kg/ms]

    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
%Equations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fl = 1 + 3.1*eh.^(1.5); %Friction factor based on Louis (1969)
Q = m_fracture/rho_w; %Volumetric flow rate
Re = rho_w*2*Q.*h./(h.*w*mu);
ke = h.^2./(12*fl);
dL = 0.5*(L - (L-2*w/2)-0.5*3.14*re);

dPtot = (mu*Q)./(h.*ke).*( (2*log(re/rw)/theta) + ((2*dL+L)/w) ); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%PLOTS%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% figure(1)
% plot(m_fracture(1,:)/w,dPtot(1,:)/10^6,m_fracture(1,:)/w,dPtot(2,:)/10^6,m_fracture(1,:)/w,dPtot(3,:)/10^6,m_fracture(1,:)/w,dPtot(4,:)/10^6,m_fracture(1,:)/w,dPtot(5,:)/10^6,m_fracture(1,:)/w,dPtot(6,:)/10^6,m_fracture(1,:)/w,dPtot(7,:)/10^6,m_fracture(1,:)/w,dPtot(8,:)/10^6)
% xlabel('Mass flow per unit width [kg/(s m)]')
% ylabel('Pressure drop [MPa]')
% legend({['h =',num2str(h(1,1)*1000),'mm'],['h =',num2str(h(2,1)*1000),'mm'],['h =',num2str(h(3,1)*1000),'mm'],['h =',num2str(h(4,1)*1000),'mm'],['h =',num2str(h(5,1)*1000),'mm'],['h =',num2str(h(6,1)*1000),'mm'],['h =',num2str(h(7,1)*1000),'mm'],['h =',num2str(h(8,1)*1000),'mm']})
% title({'Pressure drop as a function of fracture aperture and mass flow per unit width';['e/h =',num2str(eh),' and frature length =',num2str(L),'m and fracture width = ',num2str(w),'m']})

% figure(2)
% plot(L(1,:),dPtot(1,:)/10^6,L(1,:),dPtot(2,:)/10^6,L(1,:),dPtot(3,:)/10^6,L(1,:),dPtot(4,:)/10^6,L(1,:),dPtot(5,:)/10^6,L(1,:),dPtot(6,:)/10^6,L(1,:),dPtot(7,:)/10^6,L(1,:),dPtot(8,:)/10^6)
% xlabel('Fracture length [m]')
% ylabel('Pressure drop [MPa]')
% legend({['h =',num2str(h(1,1)*1000),'mm'],['h =',num2str(h(2,1)*1000),'mm'],['h =',num2str(h(3,1)*1000),'mm'],['h =',num2str(h(4,1)*1000),'mm'],['h =',num2str(h(5,1)*1000),'mm'],['h =',num2str(h(6,1)*1000),'mm'],['h =',num2str(h(7,1)*1000),'mm'],['h =',num2str(h(8,1)*1000),'mm']})
% title({'Pressure drop as a function of fracture aperture and fracture length';['e/h =',num2str(eh),' and mass flow per unit width =',num2str(m_fracture/w),'kg/(s m) and fracture width = ',num2str(w),'m']})

% figure(3)
% plot(h(:,1)*1000,dPtot(:,1)/10^6,h(:,1)*1000,dPtot(:,2)/10^6,h(:,1)*1000,dPtot(:,3)/10^6,h(:,1)*1000,dPtot(:,4)/10^6,h(:,1)*1000,dPtot(:,5)/10^6,h(:,1)*1000,dPtot(:,6)/10^6,h(:,1)*1000,dPtot(:,7)/10^6,h(:,1)*1000,dPtot(:,8)/10^6)
% xlabel('fracture aperture [mm]')
% ylabel('Pressure drop [MPa]')
% legend({['h =',num2str(h(1,1)*1000),'mm'],['h =',num2str(h(2,1)*1000),'mm'],['h =',num2str(h(3,1)*1000),'mm'],['h =',num2str(h(4,1)*1000),'mm'],['h =',num2str(h(5,1)*1000),'mm'],['h =',num2str(h(6,1)*1000),'mm'],['h =',num2str(h(7,1)*1000),'mm'],['h =',num2str(h(8,1)*1000),'mm']})
% title({'Pressure drop as a function of fracture aperture and
% roughness/aperture ratio';['Mass flow per unit width =',num2str(m_fracture/w),'kg/(s m) - fracture length = ',num2str(L),'m and fracture width = ',num2str(w),'m']})

% figure(4)
% plot(m_fracture(1,:)/w,Re(1,:))
% xlabel('Mass flow per unit width [kg/(s m)]')
% ylabel('Reynolds number')
% title({'Reynolds number as a function of mass flow per unit width';['e/h =',num2str(eh),' and frature length =',num2str(L),'m and fracture width = ',num2str(w),'m']})

figure(5)
plot(h(:,1)*1000,ke(:,1),h(:,1)*1000,ke(:,2),h(:,1)*1000,ke(:,3),h(:,1)*1000,ke(:,4),h(:,1)*1000,ke(:,5),h(:,1)*1000,ke(:,6),h(:,1)*1000,ke(:,7),h(:,1)*1000,ke(:,8))
xlabel('Fracture aperture [mm]')
ylabel('Effective permeability [m^2]')
legend(['e/h = ',num2str(eh(1,1))],['e/h = ',num2str(eh(1,2))],['e/h = ',num2str(eh(1,3))],['e/h = ',num2str(eh(1,4))],['e/h = ',num2str(eh(1,5))],['e/h = ',num2str(eh(1,6))],['e/h = ',num2str(eh(1,7))],['e/h = ',num2str(eh(1,8))])
title({'Effective permeability as a function of fracture aperture and roughness/aperture ratio';['Mass flow per unit width =',num2str(m_fracture/w),'kg/(s m) - fracture length = ',num2str(L),'m and fracture width = ',num2str(w),'m']})