%Estimation of pressure loss in fracture and near wellbore
function [m_fracture] = mfrac(L,w,H_f1,H_f2,n1,n2,dPtot)
%Physical parameters


%properties
re = w/2;
rw = 0.15;

eh = 0.7; %Roughness divided by fracture aperture
theta = pi;
%physical properties Water
    Cp_w = 4250; %specific heat of water [J/kg K]
    rho_w = 950; %Density water [kg/m^3]
    k_w = 0.68; %Thermal conductivity of water [W/mK]
    mu = 0.260*10^(-3); %dynamic viscosity [kg/ms]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
%Calculations%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%total mass flow
[m_totalfracture m_totalfractureTOT] = mfrac1(L,w,dPtot,H_f1);

%new pressure
[dP] = deltaP(m_totalfractureTOT,w,L,H_f1,H_f2);

%mass in each fracture
[m_f1] = mfracMIX(L,w,dP,H_f1,H_f2);


error = (n1 + n2)*m_totalfracture - n1*m_f1(1) - n2*m_f1(2)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%nested functions%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%total mass flow
function [m_totalfracture m_totalfractureTOT] = mfrac1(L,w,dPtot,H_f)
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
%Equations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fl = 1 + 3.1*eh.^(1.5); %Friction factor based on Louis (1969)
ke = H_f.^2./(12*fl);
dL = 0.5*(L - (L-2*w/2)-0.5*3.14*re);

m_totalfractureTOT = (rho_w)*dPtot*H_f^3/(12*mu*fl)*( ( (2*log(re/rw)/theta) + ((2*dL+L)/w) )^(-1)  )
m_totalfracture = m_totalfractureTOT/w;
end

%new pressure
function [dP] = deltaP(m_totalfractureTOT,w,L,H_f1,H_f2)
%setting up parameters for equation%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%frcature 1
fl = 1 + 3.1*eh.^(1.5); %Friction factor based on Louis (1969)
ke = H_f1.^2./(12*fl);
dL = 0.5*(L - (L-2*w/2)-0.5*3.14*re);

%fracture 2
fl = 1 + 3.1*eh.^(1.5); %Friction factor based on Louis (1969)
ke = H_f2.^2./(12*fl);
dL = 0.5*(L - (L-2*w/2)-0.5*3.14*re);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Set up equation%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%F = n1*m_fracture1 + n2*m_fracture2 - (n1 + n2)*m_totalfracture 

X0 = [0.001]*10^6;           % Make a starting guess at the solution
[x,fval] = fsolve(@equation,X0);  % Call solver
dP = x;


    function [F] = equation(X)
    F = n1*(rho_w)*X(1)*H_f1^3/(12*mu*fl)*( ( (2*log(re/rw)/theta) + ((2*dL+L)/w) )^(-1)  ) + n2*(rho_w)*X(1)*H_f2^3/(12*mu*fl)*( ( (2*log(re/rw)/theta) + ((2*dL+L)/w) )^(-1)  ) - (n1 + n2)*m_totalfractureTOT; 
    end
    
    
end

%mass flow each fracture
function [m_f1] = mfracMIX(L,w,dP,H_f1,H_f2)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
%Equations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%fracture 1
fl = 1 + 3.1*eh.^(1.5); %Friction factor based on Louis (1969)
dL = 0.5*(L - (L-2*w/2)-0.5*3.14*re);

m_fracture1 = (rho_w)*dP*H_f1^3/(12*mu*fl)*( ( (2*log(re/rw)/theta) + ((2*dL+L)/w) )^(-1)  )
m_totalfracture1 = m_fracture1/w;

%fracture 2
fl = 1 + 3.1*eh.^(1.5); %Friction factor based on Louis (1969)

dL = 0.5*(L - (L-2*w/2)-0.5*3.14*re);

m_fracture2 = (rho_w)*dP*H_f2^3/(12*mu*fl)*( ( (2*log(re/rw)/theta) + ((2*dL+L)/w) )^(-1)  )
m_totalfracture2 = m_fracture2/w;

%%%
m_f1 = [m_totalfracture1,m_totalfracture2];
end

end
