%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%EGS fracture operation calculation
%MAIN function file
%
%Call wellbore, fracture/fluidflow, pressure loss functions
%
%Lars Anders Drange, spring 2011
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [] = mainEGS()
clc;close all %remove text and open figures

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Specify parameters%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    L = 800; %length [m]
    H = 25; %hight [m]
    W = 1; %width [m] - SET TO 1 due to unity

    nx = 600;%nodes in x-direction
    
    ny = 30; %nodes in y-direction
   
%Time 
    nt = 800; %number of timesteps
    t_y= 60; %total time [years]
%Inital conditions
    Tinlet = 80; %inlet temperature of fluid [C]
    
%Geothermal conditions
    K = 0.055; %Geothermal temperature coefficient
    Tcrust = 25; %Crust surface temperature 
    Depth = 3000; %Vertical depth of reservoir [m]
    Tinitial = K*Depth + Tcrust; %Initial formation temperature [C]

    r1 = 0.12; %Inner radius of wellbore [m]
    r2 = 0.15; %Outer radius of wellbore [m]
%flow conditions
    m1 = [0.5 1 2 4 8 16]; %Total massflow [kg/s]
    n_f = 500; %number of fractures
    H_f = 2/1000; %hight of fracture [m]
    Cp_wavg = 4250; 
    
%Display info%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp(['Estimated runtime is =',num2str(runtime(nx,ny,nt)/60),' minutes'])



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
%Fracture and fluid flow calculation%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %[Tflow TmatrixSTORED X Y] = EGSdisc_twofunc(nx,ny,L,H,W,nt,t_y,Tinitial,Tin,m,n_f,H_f);
for ij = 1:length(m1)
    m = m1(ij);
        tic;
        [TfracOUT Tflow Tmatrix t_vector] = EGSdisc(nx,ny,L,H,W,nt,t_y,Tinitial,Tinlet,m,n_f,H_f,K,Tcrust,Depth,r1,r2);
        runtime1 = toc/60;disp(['actual runtime was ',num2str(runtime1),' minutes']);
        TfracOUTstored{ij} = TfracOUT;
        %Calculate total heat flow
end
        
        
 PLOTSfinal(TfracOUTstored,Tflow,Tmatrix,t_vector,m1,n_f)        
end

%runtime estimation
function [runtime_estimated] = runtime(nx,ny,nt)
    %total number of nodes
    n = ny*nx; 
    %Fitted equation
    runtime_estimated_cycle = - 2.2e-025*n^(5) + 1.3e-019*n^(4) - 1.2e-014*n^(3) + 4.6e-010*n^(2) + 4.2e-006*n + 0.0059;    
    
    runtime_estimated = runtime_estimated_cycle*nt;
end

%Final plots
function [] = PLOTSfinal(TfracOUTstored,Tflow,Tmatrix,t_vector,m1,n_f)



figure(23)
plot(t_vector/(365*24*60*60),TfracOUTstored{1},t_vector/(365*24*60*60),TfracOUTstored{2},t_vector/(365*24*60*60),TfracOUTstored{3},t_vector/(365*24*60*60),TfracOUTstored{4},t_vector/(365*24*60*60),TfracOUTstored{5},t_vector/(365*24*60*60),TfracOUTstored{6})
xlabel('Time [years]')
ylabel('Temperature [C]')
title('Temperature bottom of production well')
legend({[num2str(m1(1)/n_f),'kg/s per unit width'],[num2str(m1(2)/n_f),'kg/s per unit width'],[num2str(m1(3)/n_f),'kg/s per unit width'],[num2str(m1(4)/n_f),'kg/s per unit width'],[num2str(m1(5)/n_f),'kg/s per unit width'],[num2str(m1(6)/n_f),'kg/s per unit width']})

%legend({['mass flow in fracture = ',num2str(m1(1)/n_f),'kg/s per unit width'],['mass flow in fracture = ',num2str(m1(2)/n_f),'kg/s per unit width'],['mass flow in fracture = ',num2str(m1(3)/n_f),'kg/s per unit width'],['mass flow in fracture = ',num2str(m1(4)/n_f),'kg/s per unit width'],['mass flow in fracture = ',num2str(m1(5)/n_f),'kg/s per unit width'],['mass flow in fracture = ',num2str(m1(6)/n_f),'kg/s per unit width']})

end
