%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%EGS fracture operation calculation
%MAIN function file
%
%Call wellbore, fracture/fluidflow, pressure loss functions
%
%Lars Anders Drange, spring 2011
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [m_f1,ToutTIME,H_f1,Tout,deltaPlin1,QegsSTORED,TfracOUT,Tflow,Tmatrix,Tinjection,TproductionSTORED,t_vector,m,n_f,t_y,L,H] = mainEGS()
clc;close all %remove text and open figures

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Specify parameters%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    L = 600; %length [m]
    H1 = [5 10 15 25]; %hight [m]
    w = 150; %width [m] - SET TO 1 due to unity
    W = 1;
    
    H_f1 = 0.8/1000; %fracture aperture [m]
    H_f2 = 0.8/1000; %short circuit aperture
    
    n1 = 16; %number ordinary fractures
    n2 = 1;  %number of short circuit fractures
    
    nx = 400; %nodes in x-direction
    ny = 10; %nodes in y-direction
   
    dPtot = 0.25*10^6; %Design pressure [Pa]
    
%Time 
    nt = 200; %number of timesteps
    t_y= 20; %total time [years]
    
%Inital conditions
    Tinlet = 60; %inlet temperature of fluid [C]
    
%Geothermal conditions
    K = 0.027; %Geothermal temperature coefficient
    Tcrust = 25; %Crust surface temperature 
    Depth = 5000; %Vertical depth of reservoir [m]
    Tinitial = K.*Depth + Tcrust; %Initial formation temperature [C]

    r1 = 0.12; %Inner radius of wellbore [m]
    r2 = 0.15; %Outer radius of wellbore [m]
    
%flow conditions
    Cp_wavg = 4250; 
    m = 80; %total mass flow down wellbore [kg/s] only relevant for wellbore temp profile
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
%Fracture and fluid flow calculation%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for ij = 1:length(H1)
    H = H1(ij)

     [m_f1 dP] = mfrac(L,w,H_f1,H_f2,n1,n2,dPtot); %calculates mass flow and pressure for short circuits
        H_f11 = [H_f1, H_f1, H_f2];
        m_f11{ij} =m_f1;
      
    for jjj = 1:length(m_f1)
               m_f = m_f1(jjj)
               H_f = H_f11(jjj) 
        tic;
        [TfracOUT Tflow Tmatrix Tinjection Tproduction t_vector] = EGSdisc(nx,ny,L,H,W,nt,t_y,Tinitial,Tinlet,m,H_f,K,Tcrust,Depth,r1,r2,m_f);
%         runtime1{ij} = toc/60;disp(['actual runtime was ',num2str(runtime1),' minutes']);
        Tout{ij}(jjj) = TfracOUT(end);
        ToutTIME{ij}(jjj,:) = TfracOUT;
    
       
    end
end
      
 PLOTSfinal(t_vector,ToutTIME,dPtot,L,w,H_f1,H,t_y,dP,H_f2,n1,n2,m_f11,Cp_wavg,Tinlet)
end

%runtime estimation
function [runtime_estimated] = runtime(nx,ny,nt)
    %total number of nodes
    n = ny*nx; 
    %Fitted equation
    runtime_estimated_cycle = - 2.2e-025*n^(5) + 1.3e-019*n^(4) - 1.2e-014*n^(3) + 4.6e-010*n^(2) + 4.2e-006*n + 0.0059;    
    
    runtime_estimated = runtime_estimated_cycle*nt;
end

%Final plots
function [] = PLOTSfinal(t_vector,ToutTIME,dPtot,L,w,H_f1,H,t_y,dP,H_f2,n1,n2,m_f11,Cp_wavg,Tinlet)
% figure(1)
% plot(t_vector/(365*24*60*60),ToutTIME(1,:),t_vector/(365*24*60*60),ToutTIME(2,:),t_vector/(365*24*60*60),ToutTIME(3,:))
% ylabel('Temperature [C]')
% xlabel('Time [years]')
% title({'Temperature profile for different fracture aperture and pressure loss';['design pressure drop = ',num2str(dPtot/10^6),'MPa and short circuit pressure drop = ',num2str(dP/10^6),'MPa']})
% legend(['original (',num2str(H_f1*1000),'mm)'],['aperture =',num2str(H_f1*1000),'mm'],['aperture = ',num2str(H_f2*1000),'mm'])
% 
% figure(2)
% Tbulk1 = (n1*m_f1(2)*ToutTIME(2,:) + n2*m_f1(3)*ToutTIME(3,:))/( (n1+n2)*m_f1(1));
% plot(t_vector/(365*24*60*60),Tbulk1,t_vector/(365*24*60*60),ToutTIME(2,:),t_vector/(365*24*60*60),ToutTIME(3,:))
% ylabel('Temperature [C]')
% xlabel('Time [years]')
% title({'Bulk temperature and fracture outlet temperature';['frature length = ',num2str(L),' m - fracture spacing = ',num2str(H*2),'m - fracture width = ',num2str(w),'m'];['ratio short circuit fracture/original = ',num2str(n2/(n1+n2))]})
% legend('Tbulk',['aperture =',num2str(H_f1*1000),'mm'],['aperture = ',num2str(H_f2(1)*1000),'mm (',num2str(n2/(n1+n2)),')'])
% 
% figure(3)
m_f11
for i =1:4
Tbulk1{i} = (n1*m_f11{i}(2)*ToutTIME{i}(2,:) + n2*m_f11{i}(3)*ToutTIME{i}(3,:))/( (n1+n2)*m_f11{i}(1));
end
% Tnorm1 = Tbulk1./ToutTIME(1,:);
% plot(t_vector/(365*24*60*60),Tnorm1)
% ylabel('Temperature [C]')
% xlabel('Time [years]')
% title({'Normalized bulk temperature';['frature length = ',num2str(L),' m - fracture spacing = ',num2str(H*2),'m - fracture width = ',num2str(w),'m'];['design pressure drop = ',num2str(dPtot/10^6),'MPa - short circuit pressure drop = ',num2str(dP/10^6),'MPa']})
% legend({['aperture = ',num2str(H_f1*1000),'mm and ',num2str(n2/(n1+n2)*100),'% aperture of ',num2str(H_f2(1)*1000),'mm']})
% 
% 
% figure(4)
% bar(m_f1,1.5)
% ylabel('Mass flow per unit width [kg/(s m)]')
% title({'Mass flow per unit width in each frature';['frature length = ',num2str(L),' m - fracture spacing = ',num2str(H*2),'m - fracture width = ',num2str(w),'m'];['ratio short circuit fracture/original = ',num2str(n2/(n1+n2))]})
% 
% figure(5)
% Qegs = Cp_wavg*m_f1(1)*w*(n1+n2)*(ToutTIME(1,:) - Tinlet)/10^6;

for j =1:4
QegsShort{j} = Cp_wavg*m_f11{j}(1)*w*(n1+n2)*(Tbulk1{j} - Tinlet)/10^6;
end
% plot(t_vector/(365*24*60*60),Qegs(1,:),t_vector/(365*24*60*60),QegsShort)
% ylabel('Extracted heat [MW]')
% xlabel('Time [years]')
% title({'Extracted heat as a function of time';['frature length = ',num2str(L),' m - fracture spacing = ',num2str(H*2),'m - fracture width = ',num2str(w),'m'];['total mass flow = ',num2str(m_f1(1)*w*(n1+n2)),'kg/s and constant Cp = ',num2str(Cp_wavg),'J/kg K']})
% legend({['uniform aperture = ',num2str(H_f1*1000),'mm'],
%         ['aperture = ',num2str(H_f1*1000),'mm and ',num2str(n2/(n1+n2)*100),'% aperture of ',num2str(H_f2(1)*1000),'mm']})

%write to excel
dataEXCEL = [QegsShort{1};Tbulk1{1};QegsShort{2};Tbulk1{2};QegsShort{3};Tbulk1{3};QegsShort{4};Tbulk1{4};t_vector];

xlswrite('datafromEGSprogram.xls', dataEXCEL,'EGSdata')



end

%Mass flow in each fracture calculation based on known pressure drop
function [m_fracture dP] = mfrac(L,w,H_f1,H_f2,n1,n2,dPtot)
%Physical parameters


%properties
re = w/2;
rw = 0.15;

eh = 0.7; %Roughness divided by fracture aperture
theta = pi;
%physical properties Water
    Cp_w = 4250; %specific heat of water [J/kg K]
    rho_w = 950; %Density water [kg/m^3]
    k_w = 0.68; %Thermal conductivity of water [W/mK]
    mu = 0.260*10^(-3); %dynamic viscosity [kg/ms]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
%Calculations%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%total mass flow
[m_totalfracture m_totalfractureTOT] = mfrac1(L,w,dPtot,H_f1);

%new pressure
[dP] = deltaP(m_totalfractureTOT,w,L,H_f1,H_f2);

%mass in each fracture
[m_f1] = mfracMIX(L,w,dP,H_f1,H_f2);

%mass flow
m_fracture = [m_totalfracture m_f1(1) m_f1(2)];

error = -(n1 + n2)*m_totalfracture + n1*m_f1(1) + n2*m_f1(2);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%nested functions%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%total mass flow
function [m_totalfracture m_totalfractureTOT] = mfrac1(L,w,dPtot,H_f)
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
%Equations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fl = 1 + 3.1*eh.^(1.5); %Friction factor based on Louis (1969)
ke = H_f.^2./(12*fl);
dL = 0.5*(L - (L-2*w/2)-0.5*3.14*re);

m_totalfractureTOT = (rho_w)*dPtot*H_f^3/(12*mu*fl)*( ( (2*log(re/rw)/theta) + ((2*dL+L)/w) )^(-1)  );
m_totalfracture = m_totalfractureTOT/w;
end

%new pressure
function [dP] = deltaP(m_totalfractureTOT,w,L,H_f1,H_f2)
%setting up parameters for equation%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%frcature 1
fl = 1 + 3.1*eh.^(1.5); %Friction factor based on Louis (1969)
ke = H_f1.^2./(12*fl);
dL = 0.5*(L - (L-2*w/2)-0.5*3.14*re);

%fracture 2
fl = 1 + 3.1*eh.^(1.5); %Friction factor based on Louis (1969)
ke = H_f2.^2./(12*fl);
dL = 0.5*(L - (L-2*w/2)-0.5*3.14*re);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Set up equation%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%F = n1*m_fracture1 + n2*m_fracture2 - (n1 + n2)*m_totalfracture 

X0 = [0.001]*10^6;           % Make a starting guess at the solution
[x,fval] = fsolve(@equation,X0);  % Call solver
dP = x;


    function [F] = equation(X)
    F = n1*((rho_w)*X(1)*H_f1^3/(12*mu*fl)*( ( (2*log(re/rw)/theta) + ((2*dL+L)/w) )^(-1)  )) + n2*((rho_w)*X(1)*H_f2^3/(12*mu*fl)*( ( (2*log(re/rw)/theta)) + ((2*dL+L)/w) )^(-1)  ) - (n1 + n2)*m_totalfractureTOT; 
    end
    
    
end

%mass flow each fracture
function [m_f1] = mfracMIX(L,w,dP,H_f1,H_f2)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
%Equations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%fracture 1
fl = 1 + 3.1*eh.^(1.5); %Friction factor based on Louis (1969)
dL = 0.5*(L - (L-2*w/2)-0.5*3.14*re);

m_fracture1 = (rho_w)*dP*H_f1^3/(12*mu*fl)*( ( (2*log(re/rw)/theta) + ((2*dL+L)/w) )^(-1)  );
m_totalfracture1 = m_fracture1/w

%fracture 2
fl = 1 + 3.1*eh.^(1.5); %Friction factor based on Louis (1969)

dL = 0.5*(L - (L-2*w/2)-0.5*3.14*re);

m_fracture2 = (rho_w)*dP*H_f2^3/(12*mu*fl)*( ( (2*log(re/rw)/theta) + ((2*dL+L)/w) )^(-1)  );
m_totalfracture2 = m_fracture2/w

%%%
m_f1 = [m_totalfracture1,m_totalfracture2]
end

end